function removeEmojis(text)
    local emoji_ranges = {
        {0x1F600, 0x1F64F}, -- Emoticons
        {0x1F300, 0x1F5FF}, -- Miscellaneous Symbols and Pictographs
        {0x1F680, 0x1F6FF}, -- Transport and Map Symbols
        {0x1F700, 0x1F77F}, -- Alchemical Symbols
        {0x1F780, 0x1F7FF}, -- Geometric Shapes Extended
        {0x1F800, 0x1F8FF}, -- Supplemental Arrows-C
        {0x1F900, 0x1F9FF}, -- Supplemental Symbols and Pictographs
        {0x1FA00, 0x1FA6F}, -- Chess Symbols
        {0x1FA70, 0x1FAFF}, -- Symbols and Pictographs Extended-A
        {0x2600, 0x26FF},   -- Miscellaneous Symbols
        {0x2700, 0x27BF},   -- Dingbats
        {0xFE00, 0xFE0F},   -- Variation Selectors
        {0x1F1E6, 0x1F1FF}, -- Regional Indicator Symbols
        {0x1F900, 0x1F9FF}, -- Supplemental Symbols and Pictographs
        {0x200D, 0x200D},   -- Zero Width Joiner
        {0x20E3, 0x20E3},   -- Combining Enclosing Keycap
        {0x1F018, 0x1F270}, -- Various Symbols
    }

    local function isEmoji(char)
        local code = utf8.codepoint(char)
        for _, range in ipairs(emoji_ranges) do
            if code >= range[1] and code <= range[2] then
                return true
            end
        end
        return false
    end

    local clean_text = ""
    for _, char in utf8.codes(text) do
        local character = utf8.char(char)
        if isEmoji(character) then
            clean_text = clean_text .. " "
        else
            clean_text = clean_text .. character
        end
    end

    -- إزالة المسافات الزائدة المتتالية مع الحفاظ على الأسطر الجديدة
    clean_text = clean_text:gsub("[ \t]+", " ")

    return clean_text
end

local input = service.getText(node)
local output = removeEmojis(input)
service.speak(output)  -- الناتج: "Hello ! How are you ?"